#include "../include/GameManager.h"

GameManager::GameManager()
{
    SDL_Init( SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_TIMER);
    TTF_Init();
    Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 1024);

    const SDL_VideoInfo* videoInfo = SDL_GetVideoInfo();
    monitorw = videoInfo->current_w;
    monitorh = videoInfo->current_h;
    screen = SDL_SetVideoMode(1024, 768, 16, SDL_SWSURFACE | SDL_FULLSCREEN);

    timer = SDL_GetTicks();

    manex = (FPSmanager*) malloc(sizeof(FPSmanager));
    SDL_initFramerate(manex);
    SDL_setFramerate(manex, 30);

    currentState = new SplashState();
    currentState->load(p1, p2);

    inputManager = new InputManager();

    p1 = new Player(true);
    p2 = new Player(false);

    renderPlayer = false;
}

GameManager::~GameManager()
{

    //dtor
}

void GameManager::run()
{
    bool loop = true;
    Uint32 atimer, dt;

    while(loop) {
        atimer = timer;
        timer = SDL_GetTicks();
        dt = timer - atimer;

        inputManager->update();

        switch(currentState->update(dt, inputManager, p1, p2)) {
            case 1:
                currentState->unload();
                currentState = new SplashState();
                currentState->load(p1, p2);
                renderPlayer = false;
            break;
            case 2:
                p1->hp = 120;
                p2->hp = 120;
                currentState->unload();
                currentState = new Level1State();
                currentState->load(p1, p2);
                renderPlayer = true;
            break;
            case 3:
                currentState->unload();
                currentState = new Level2State();
                currentState->load(p1, p2);
                renderPlayer = true;
            break;
            case 4:
                currentState->unload();
                currentState = new Level3State();
                currentState->load(p1, p2);
                renderPlayer = true;
            break;
            case 5:
                currentState->unload();
                currentState = new GameOver();
                currentState->load(p1, p2);
                renderPlayer = false;
            break;
            case 6:
                currentState->unload();
                currentState = new SurvivedState(1);
                currentState->load(p1, p2);
                renderPlayer = false;
            break;
            case 7:
                currentState->unload();
                currentState = new SurvivedState(2);
                currentState->load(p1, p2);
                renderPlayer = false;
            break;
        }

        p1->Update();
        p2->Update();

        //Limpa a tela.
        SDL_FillRect(screen, 0, SDL_MapRGB(screen->format, 0, 0, 0));

        currentState->render(screen, p1, p2);

        SDL_framerateDelay(manex);

        if (inputManager->isKeyPressed(SDLK_ESCAPE)) {
            loop = false;
        }

        //atualizando a tela
        SDL_Flip(screen);
    }
    screen = SDL_SetVideoMode(monitorw, monitorh, 16, SDL_SWSURFACE | SDL_FULLSCREEN);
}
