#include "../include/InputManager.h"

InputManager* InputManager::instance = NULL;

InputManager::InputManager()
{
    keyState = SDL_GetKeyState(NULL);
}

InputManager::~InputManager()
{
    //dtor
}

void InputManager::update()
{
    SDL_Event event;

    events.clear();
    while(SDL_PollEvent(&event)) {
            events.push_back(event);
    }
}

bool InputManager::isKeyDown(int key)
{
    for(eventsIt=events.begin(); eventsIt!=events.end(); eventsIt++) {
        if(eventsIt->type == SDL_KEYDOWN) {
            if(eventsIt->key.keysym.sym == key) {
                return true;
            }
        }
    }
    return false;
}

bool InputManager::isKeyUp(int key)
{
    for(eventsIt=events.begin(); eventsIt!=events.end(); eventsIt++) {
        if(eventsIt->type == SDL_KEYUP) {
            if(eventsIt->key.keysym.sym == key) {
                return true;
            }
        }
    }
    return false;
}

bool InputManager::isKeyPressed(int key)
{
    if(keyState[key]) {
        printf("%c\n", key);
        return true;
    }
    return false;
}

bool InputManager::isMouseDown(int button)
{
    for(eventsIt=events.begin(); eventsIt!=events.end(); eventsIt++) {
        if(eventsIt->type == SDL_MOUSEBUTTONDOWN) {
            if(eventsIt->button.button == button) {
                return true;
            }
        }
    }
    return false;
}

bool InputManager::isMouseUp(int button)
{
    for(eventsIt=events.begin(); eventsIt!=events.end(); eventsIt++) {
        if(eventsIt->type == SDL_MOUSEBUTTONUP) {
            if(eventsIt->button.button == button) {
                return true;
            }
        }
    }
    return false;
}

bool InputManager::isMousePressed(int button)
{
    return (SDL_GetMouseState(NULL, NULL) & SDL_BUTTON(button));
}

int InputManager::mousePosx()
{
    int* x = (int*) malloc(sizeof(int));
    SDL_GetMouseState(x, NULL);
    return *x;
}

int InputManager::mousePosy()
{
    int* y = (int*) malloc(sizeof(int));
    SDL_GetMouseState(NULL, y);
    return *y;
}

bool InputManager::isMouseInside(Sprite* sprite)
{
    return ((mousePosx() >= sprite->x) && (mousePosx() <= (sprite->x + sprite->rectangle->w)) && (mousePosy() >= sprite->y) && (mousePosy() <= (sprite->y + sprite->rectangle->h)));
}

bool InputManager::isMouseInside(Text* texto)
{
    return ((mousePosx() >= texto->x) && (mousePosx() <= (texto->x + texto->rect.w)) && (mousePosy() >= texto->y) && (mousePosy() <= (texto->y + texto->rect.h)));
}

InputManager* InputManager::getInstance()
{
    if(!instance) {
        instance = new InputManager();
    }
    return instance;
}
