#include "../include/Sprite.h"

Sprite::Sprite(std::string fileName, int x, int y)
{
    this->fileName = fileName;
    this->x = x;
    this->y = y;
    surface = IMG_Load(fileName.c_str());
    rectangle = new SDL_Rect();
    rectangle->x = x;
    rectangle->y = y;
    rectangle->w = surface->w;
    rectangle->h = surface->h;
    surfaceRotoZoom = NULL;
    rectRotoZoom = new SDL_Rect();
    rectRotoZoom->w = surface->w;
    rectRotoZoom->h = surface->h;
    rectRotoZoom->x = x;
    rectRotoZoom->y = y;
    angle = 0;
    zoom = 1;
}

Sprite::~Sprite()
{
    SDL_FreeSurface(surface);
    SDL_FreeSurface(surfaceRotoZoom);
    if (rectangle) {
        delete rectangle;
        rectangle = 0;
    }
    if (rectRotoZoom) {
        delete rectRotoZoom;
        rectRotoZoom = 0;
    }
}

void Sprite::Render(SDL_Surface* screen)
{
    rectangle->x = x;
    rectangle->y = y;
    rectRotoZoom->x = x;
    rectRotoZoom->y = y;
    if((zoom == 1) && (angle == 0)) {
        SDL_BlitSurface(surface, NULL, screen, rectangle);
    }
    else {
        SDL_BlitSurface(surfaceRotoZoom, NULL, screen, rectRotoZoom);
    }
}

void Sprite::UpdatePos(int x, int y)
{
    this->x = x;
    this->y = y;
}

SDL_Rect* Sprite::GetRect()
{
    rectangle->x = x;
    rectangle->y = y;
    return rectangle;
}

bool Sprite::boxCollidesWith(Sprite* sprite)
{
    if(((x - sprite->x) < sprite->rectangle->w) && ((sprite->x - x) < rectangle->w) && ((y - sprite->y) < sprite->rectangle->h) && ((sprite->y - y) < rectangle->h)) {
        return true;
    }
    return false;
}

void Sprite::setZoom(double zoom) {
    SDL_FreeSurface(surfaceRotoZoom);
    this->zoom = zoom;
    surfaceRotoZoom = rotozoomSurface(surface, angle, zoom, 1);
    rectRotoZoom->w = surfaceRotoZoom->w;
    rectRotoZoom->h = surfaceRotoZoom->h;
}

void Sprite::setRot(double angle) {
    SDL_FreeSurface(surfaceRotoZoom);
    this->angle = angle;
    float w = rectRotoZoom->w;
    float h = rectRotoZoom->h;
    surfaceRotoZoom = rotozoomSurface(surface, angle, zoom, 1);
    rectRotoZoom->w = surfaceRotoZoom->w;
    rectRotoZoom->h = surfaceRotoZoom->h;
    x = x + (surfaceRotoZoom->w - w) / 2;
    y = y - (surfaceRotoZoom->h - h) / 2;
}
