#include "../include/Text.h"

Text::Text(std::string fontFile, float x, float y, int style, int red, int green, int blue, int psize, std::string text)
{
    this->fontFile = fontFile;
    this->x = x;
    this->y = y;
    this->style = style;
    this->psize = psize;
    this->text = text;
    color.r = red;
    color.g = green;
    color.b = blue;

    font = TTF_OpenFont(fontFile.c_str(), psize);
    textSurface = TTF_RenderText_Blended(font, text.c_str(), color);
    rect.x = x;
    rect.y = y;
    rect.w = textSurface->w;
    rect.h = textSurface->h;
}

Text::~Text()
{
    TTF_CloseFont(font);
    SDL_FreeSurface(textSurface);
}

void Text::render(SDL_Surface* screen)
{
    rect.x = x;
    rect.y = y;
    SDL_BlitSurface(textSurface, NULL, screen, &rect);
}

void Text::changeText(std::string text)
{
    SDL_FreeSurface(textSurface);
    this->text = text;
    textSurface = TTF_RenderText_Blended(font, text.c_str(), color);
}

void Text::changeStyle(int style)
{
    SDL_FreeSurface(textSurface);
    TTF_SetFontStyle(font, style);
    textSurface = TTF_RenderText_Blended(font, text.c_str(), color);
}

void Text::changeColor(int red, int green, int blue)
{
    color.r = red;
    color.g = green;
    color.b = blue;

    SDL_FreeSurface(textSurface);
    textSurface = TTF_RenderText_Blended(font, text.c_str(), color);
}

void Text::changeSize(int psize)
{
    this->psize = psize;
    SDL_FreeSurface(textSurface);
    TTF_CloseFont(font);

    font = TTF_OpenFont(fontFile.c_str(), psize);
    textSurface = TTF_RenderText_Blended(font, text.c_str(), color);
    rect.w = textSurface->w;
    rect.h = textSurface->h;
}

void Text::UpdatePos(int x, int y)
{
    this->x = x;
    this->y = y;
}
